@@ -1,4 +1,4 @@
-from typing import Optional
+from typing import Union
 
 from fastapi import FastAPI, Query
 
@@ -7,7 +7,7 @@ app = FastAPI()
 
 @app.get("/items/")
 async def read_items(
-    hidden_query: Optional[str] = Query(None, include_in_schema=False)
+    hidden_query: Union[str, None] = Query(default=None, include_in_schema=False)
 ):
     if hidden_query:
         return {"hidden_query": hidden_query}
